@@ -2,8 +2,9 @@ package WebService::MinFraud::Client;
 
 use 5.010;
 use Moo 1.004005;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use HTTP::Headers ();
 use HTTP::Request ();
@@ -44,7 +45,7 @@ has _json => (
     is       => 'ro',
     isa      => JSONObject,
     init_arg => undef,
-    default  => quote_sub(q{ JSON()->new->utf8 }),
+    default  => quote_sub(q{ JSON::MaybeXS->new->utf8 }),
 );
 has license_key => (
     is       => 'ro',
@@ -154,10 +155,7 @@ sub _response_for {
     }
     else {
         # all other error codes throw an exception
-        $self->_handle_error_status(
-            $response, $uri,
-            $content->{device}{ip_address}
-        );
+        $self->_handle_error_status( $response, $uri );
     }
 }
 
@@ -209,18 +207,17 @@ sub _handle_error_status {
     my $self     = shift;
     my $response = shift;
     my $uri      = shift;
-    my $ip       = shift;
 
     my $status = $response->code;
 
     if ( $status =~ /^4/ ) {
-        $self->_handle_4xx_status( $response, $status, $uri, $ip );
+        $self->_handle_4xx_status( $response, $status, $uri );
     }
     elsif ( $status =~ /^5/ ) {
-        $self->_handle_5xx_status( $response, $status, $uri );
+        $self->_handle_5xx_status( $status, $uri );
     }
     else {
-        $self->_handle_non_200_status( $response, $status, $uri );
+        $self->_handle_non_200_status( $status, $uri );
     }
 }
 
@@ -229,7 +226,6 @@ sub _handle_4xx_status {
     my $response = shift;
     my $status   = shift;
     my $uri      = shift;
-    my $ip       = shift;
 
     my $content = $response->decoded_content;
 
@@ -267,10 +263,9 @@ sub _handle_4xx_status {
 }
 
 sub _handle_5xx_status {
-    my $self     = shift;
-    my $response = shift;
-    my $status   = shift;
-    my $uri      = shift;
+    my $self   = shift;
+    my $status = shift;
+    my $uri    = shift;
 
     WebService::MinFraud::Error::HTTP->throw(
         message     => "Received a server error ($status) for $uri",
@@ -280,10 +275,9 @@ sub _handle_5xx_status {
 }
 
 sub _handle_non_200_status {
-    my $self     = shift;
-    my $response = shift;
-    my $status   = shift;
-    my $uri      = shift;
+    my $self   = shift;
+    my $status = shift;
+    my $uri    = shift;
 
     WebService::MinFraud::Error::HTTP->throw(
         message =>
@@ -301,13 +295,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insights web services
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
 
 =head1 SYNOPSIS
 
@@ -564,13 +560,17 @@ can check to see if the attribute is set.
       say "no phone number found for issuer";
   }
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
