@@ -4,8 +4,9 @@ use 5.010;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use parent 'Data::Rx::CommonType::EasyNew';
 
@@ -46,13 +47,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Data::Rx::Type::CCToken - A type to check for what MaxMind considers a valid credit card token
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -60,7 +67,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
