@@ -4,8 +4,9 @@ use 5.010;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Carp ();
 use DateTime::Format::RFC3339;
@@ -27,7 +28,7 @@ sub assert_valid {
 }
 
 sub guts_from_arg {
-    my ( $class, $arg, $rx ) = @_;
+    my ( $class, $arg ) = @_;
     $arg ||= {};
 
     if ( my @unexpected = keys %$arg ) {
@@ -51,13 +52,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Data::Rx::Type::DateTime::RFC3339 - A type to check if a string parses as a RFC3339 datetime
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -65,7 +72,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
