@@ -4,8 +4,9 @@ use 5.010;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use parent 'Data::Rx::CommonType::EasyNew';
 
@@ -16,7 +17,7 @@ sub assert_valid {
 }
 
 sub guts_from_arg {
-    my ( $class, $arg, $rx ) = @_;
+    my ( undef, $arg, $rx ) = @_;
 
     my $meta = $rx->make_schema(
         {
@@ -73,13 +74,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Data::Rx::Type::Enum - A type that defines an enumeration
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -87,7 +94,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
