@@ -4,8 +4,9 @@ use 5.010;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Data::Validate::URI qw(is_web_uri);
 
@@ -18,7 +19,6 @@ with 'WebService::MinFraud::Role::Data::Rx::Type';
 sub assert_valid {
     my ( $self, $value ) = @_;
 
-    my @labels = split /\./, $value;
     return 1
         if $value
         && is_web_uri($value);
@@ -45,13 +45,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Data::Rx::Type::WebURI - A type to check for a valid Web URI
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -59,7 +65,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
