@@ -1,8 +1,9 @@
 package WebService::MinFraud::Model::Factors;
 
 use Moo;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Types::Standard qw( HashRef InstanceOf );
 use WebService::MinFraud::Record::BillingAddress;
@@ -22,6 +23,10 @@ with 'WebService::MinFraud::Role::Model',
     'WebService::MinFraud::Role::HasLocales',
     'WebService::MinFraud::Role::HasCommonAttributes';
 
+## no critic (ProhibitUnusedPrivateSubroutines)
+sub _has { has(@_) }
+## use critic
+
 __PACKAGE__->_define_model_attributes(
     billing_address  => 'BillingAddress',
     credit_card      => 'CreditCard',
@@ -41,13 +46,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Model::Factors - Model class for minFraud Factors
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
 
 =head1 SYNOPSIS
 
@@ -191,13 +198,17 @@ data was present in the response body, false if otherwise:
 
 =head2 has_warnings
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
