@@ -1,8 +1,9 @@
 package WebService::MinFraud::Record::BillingAddress;
 
 use Moo;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 with 'WebService::MinFraud::Role::Record::Address';
 
@@ -14,13 +15,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Record::BillingAddress - Contains data for the billing address record associated with a transaction
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
 
 =head1 SYNOPSIS
 
@@ -59,7 +62,7 @@ country as that of the IP address.
 =head2 is_postal_in_city
 
 Returns a boolean indicating whether the billing postal code is in the
-billing city. The attribute will not be set if the address is not in USA.
+billing city.
 
 =head2 latitude
 
@@ -84,13 +87,17 @@ data was present in the response body, false if otherwise:
 
 =head2 has_longitude
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
