@@ -1,8 +1,9 @@
 package WebService::MinFraud::Record::Email;
 
 use Moo;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use WebService::MinFraud::Types qw( Bool BoolCoercion );
 
@@ -26,13 +27,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Record::Email - Contains data for the email associated with a transaction
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
 
 =head1 SYNOPSIS
 
@@ -68,13 +71,17 @@ This field is true if MaxMind believes that this email is likely to be used
 for fraud. Note that this is also factored into the overall risk_score in the
 response as well.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
