@@ -3,15 +3,16 @@ package WebService::MinFraud::Role::Data::Rx::Type;
 use strict;
 use warnings;
 use Role::Tiny;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Carp ();
 
 requires 'type_uri';
 
 sub guts_from_arg {
-    my ( $class, $arg, $rx ) = @_;
+    my ( $class, $arg ) = @_;
     $arg ||= {};
 
     if ( my @unexpected = keys %$arg ) {
@@ -30,13 +31,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Role::Data::Rx::Type - A role that helps build Data::Rx Types
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -44,7 +51,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
