@@ -1,8 +1,9 @@
 package WebService::MinFraud::Role::HasCommonAttributes;
 
 use Moo::Role;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Types::Standard qw( ArrayRef InstanceOf Num Str );
 use Types::UUID;
@@ -62,13 +63,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Role::HasCommonAttributes - A role for attributes common to both the Insights and Score models
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -76,7 +83,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
