@@ -1,12 +1,15 @@
 package WebService::MinFraud::Role::Model;
 
 use Moo::Role;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Sub::Quote qw( quote_sub );
 use Types::Standard qw( HashRef );
 
+requires '_has';
+
 has raw => (
     is       => 'ro',
     isa      => HashRef,
@@ -26,11 +29,12 @@ around BUILDARGS => sub {
     return $p;
 };
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _define_model_attributes {
     my $class  = shift;
     my %models = @_;
 
-    my $has = $class->can('has');
+    my $has = $class->can('_has');
 
     for my $key ( keys %models ) {
         my $record_class = "WebService::MinFraud::Record::$models{$key}";
@@ -66,9 +70,9 @@ sub _define_model_attributes {
                 ),
             ),
         );
-        ## use critic
     }
 }
+## use critic
 
 sub _build_record {
     my $self         = shift;
@@ -88,13 +92,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Role::Model - A role for storing there original response in the raw attribute
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -102,7 +112,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
