@@ -1,9 +1,14 @@
+## no critic (Subroutines::ProhibitExportingUndeclaredSubs)
 package WebService::MinFraud::Types;
 
 use strict;
 use warnings;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
+
+use Sub::Quote qw( quote_sub );
+
+use namespace::clean;
 
 use GeoIP2::Types qw(
     ArrayRef
@@ -23,7 +28,6 @@ use GeoIP2::Types qw(
     UserAgentObject
     object_isa_type
 );
-use Sub::Quote qw( quote_sub );
 
 use Exporter qw( import );
 
@@ -88,13 +92,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Types - Custom types for the MaxMind minFraud service
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
 
 =head1 AUTHOR
 
@@ -102,7 +112,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
