@@ -1,8 +1,9 @@
 package WebService::MinFraud::Validator;
 
 use Moo;
+use namespace::autoclean;
 
-our $VERSION = '1.003000';
+our $VERSION = '1.004000';
 
 use Data::Delete 0.05;
 use Data::Rx;
@@ -346,13 +347,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::MinFraud::Validator - Validation for the minFraud requests
 
 =head1 VERSION
 
-version 1.003000
+version 1.004000
 
 =head1 SYNOPSIS
 
@@ -378,13 +381,17 @@ This method takes a minFraud request as a HashRef and validates it against the
 minFraud request schema. If the request HashRef fails validation, an exception
 is thrown, which is a string containing all of the validation errors.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/minfraud-api-perl/issues>.
+
 =head1 AUTHOR
 
 Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2016 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2017 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
